"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Enums = void 0;
const default_1 = require("./default");
class Enums {
    constructor(enumsObj, defaultValue) {
        this.enumsObj = enumsObj;
        this.enumDefaultValue =
            defaultValue ??
                typeof enumsObj[Object.keys(enumsObj)[0]].value === "number"
                ? default_1.defaultNumberEnums
                : default_1.defaultStringEnums;
        this.enums = Object.keys(enumsObj).reduce((acc, key) => {
            acc[key] = enumsObj[key].value;
            return acc;
        }, {});
    }
    get entries() {
        return Object.entries(this.enumsObj).map(([key, value]) => ({
            key,
            ...value,
        }));
    }
    getEnumValue(val, defaultValue) {
        if (defaultValue === undefined) {
            defaultValue = this.enumDefaultValue;
        }
        if (typeof val === "number") {
            const entriesObj = Object.entries(this.enumsObj);
            for (const [k, v] of entriesObj) {
                if (v.value === val) {
                    return this.enumsObj[k];
                }
            }
        }
        else if (val in this.enumsObj) {
            return this.enumsObj[val];
        }
        return defaultValue;
    }
    swaggerPropertyOptions(description) {
        return {
            type: Number,
            enum: Object.values(this.enums),
            description: `
  --- Enum description ---    
  ${Object.values(this.enumsObj).map((v) => `value: ${v.value} = [en: ${v.en} , th: ${v.th}]`).join('\n')}
  --- description ---
  ${description}
        `
        };
    }
}
exports.Enums = Enums;
//# sourceMappingURL=enumsClass.js.map